<?php
class Advanced_Ads_Page_Peel_Admin {

	const PLUGIN_LINK = 'https://wpadvancedads.com/add-ons/page-peel-ads/';

	/**
	 * Holds base class
	 *
	 * @var Advanced_Ads_Page_Peel_Plugin
	 */
	protected $plugin;

	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 */
	public function __construct() {
		$this->plugin = Advanced_Ads_Page_Peel_Plugin::get_instance();
		add_action( 'plugins_loaded', array( $this, 'wp_admin_plugins_loaded' ) );
	}

	/**
	 * Load actions and filters
	 */
	public function wp_admin_plugins_loaded() {
		if ( ! class_exists( 'Advanced_Ads_Admin', false ) ) {
			// show admin notice
			add_action( 'admin_notices', array( $this, 'missing_plugin_notice' ) );
			return;
		}

		// add admin scripts
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
		// content of page peel placement
		add_action( 'advanced-ads-placement-options-after-advanced', array( $this, 'page_peel_placement_content' ), 10, 2 );
		// add AdSense warning
		add_action( 'advanced-ads-placement-options-after', array( $this, 'add_adsense_warning' ), 5, 2 );
	}

	/**
	 * Show warning if Advanced Ads js is not activated
	 */
	public function missing_plugin_notice() {
		$plugins = get_plugins();
		if ( isset( $plugins['advanced-ads/advanced-ads.php'] ) ) { // is installed, but not active
			$link = '<a class="button button-primary" href="' . wp_nonce_url( 'plugins.php?action=activate&amp;plugin=advanced-ads/advanced-ads.php&amp', 'activate-plugin_advanced-ads/advanced-ads.php' ) . '">' . __( 'Activate Now', 'advanced-ads-page-peel' ) . '</a>';
		} else {
			$link = '<a class="button button-primary" href="' . wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=' . 'advanced-ads' ), 'install-plugin_' . 'advanced-ads' ) . '">' . __( 'Install Now', 'advanced-ads-page-peel' ) . '</a>';
		}
		echo '<div class="error"><p>' . sprintf( __( '<strong>%s</strong> requires the <strong><a href="https://wpadvancedads.com/#utm_source=advanced-ads&utm_medium=link&utm_campaign=activate-genesis" target="_blank">Advanced Ads</a></strong> plugin to be installed and activated on your site.', 'advanced-ads-page-peel' ), 'Advanced Ads – Page Peel Ads' )
			. '&nbsp;' . $link . '</p></div>';
	}

	/**
	 * Add page peel placement styles
	 *
	 * @param type $hook_suffix
	 */
	function admin_scripts( $hook_suffix ) {
		if ( ! class_exists( 'Advanced_Ads_Admin' ) ) {
			return;
		};

		if ( Advanced_Ads_Admin::screen_belongs_to_advanced_ads() ) {
			wp_enqueue_style( 'advanced-ads-page-peel-admin-css', AACP_BASE_URL . 'admin/assets/css/admin.css', array(), AACP_VERSION );
		}

		// page peel placement admin scripts
		if ( is_admin() && isset( $_GET['page'] ) && $_GET['page'] == 'advanced-ads-placements' ) {
			wp_enqueue_script( 'wp-color-picker' );
			wp_enqueue_style( 'wp-color-picker' );
			wp_register_script( 'page-peel-admin', AACP_BASE_URL . 'admin/assets/js/admin.js', array( 'jquery' ) );
			wp_enqueue_script( 'page-peel-admin' );
		}
	}

	/**
	 * Render page peel placement content
	 *
	 * @param string $placement_slug id of the placement
	 */
	public function page_peel_placement_content( $placement_slug, $placement ) {
		// admin placement content

		switch ( $placement['type'] ) {
			case 'page_peel':
				if ( ! class_exists( 'Advanced_Ads_Admin_Options' ) ) {
					echo 'Please update to Advanced Ads 1.8';
					return;
				}

				$options = isset( $placement['options']['page_peel'] ) ? $placement['options']['page_peel'] : array();

				$option_name = "advads[placements][$placement_slug][options][page_peel]";

				// Layout
				$layout = isset( $options['layout'] ) ? $options['layout'] : 'triangle';

				ob_start();
				include AACP_BASE_PATH . '/admin/views/layout.php';
				$option_content = ob_get_clean();

				Advanced_Ads_Admin_Options::render_option(
					'placement-page-peel-layout',
					__( 'Layout', 'advanced-ads-page-peel' ),
					$option_content
				);

				// Position on the screen
				$position = isset( $placement['options']['page_peel']['position'] ) ? $placement['options']['page_peel']['position'] : 'topright';

				ob_start();
				include AACP_BASE_PATH . '/admin/views/position.php';
				$option_content = ob_get_clean();

				Advanced_Ads_Admin_Options::render_option(
					'placement-page-peel-position',
					__( 'Position', 'advanced-ads-page-peel' ),
					$option_content
				);

				// Ad start size
				$width  = isset( $options['start_width'] ) ? absint( $options['start_width'] ) : 58;
				$height = isset( $options['start_height'] ) ? absint( $options['start_height'] ) : 58;

				ob_start();
				include AACP_BASE_PATH . '/admin/views/size.php';
				$option_content = ob_get_clean();

				Advanced_Ads_Admin_Options::render_option(
					'placement-page-peel-start-size',
					__( 'Start size', 'advanced-ads-page-peel' ),
					$option_content
				);

				// Ad full size
				$full_width  = isset( $options['full_width'] ) ? absint( $options['full_width'] ) : '';
				$full_height = isset( $options['full_height'] ) ? absint( $options['full_height'] ) : '';

				ob_start();
				include AACP_BASE_PATH . '/admin/views/full-size.php';
				$option_content = ob_get_clean();

				Advanced_Ads_Admin_Options::render_option(
					'placement-page-peel-full-size',
					__( 'Full size', 'advanced-ads-page-peel' ),
					$option_content
				);

				// Peel color
				$peel_color = isset( $options['peel_color'] ) ? $options['peel_color'] : '';

				ob_start();
				include AACP_BASE_PATH . '/admin/views/peel-color.php';
				$option_content = ob_get_clean();

				Advanced_Ads_Admin_Options::render_option(
					'placement-page-peel-color',
					__( 'Page Peel color', 'advanced-ads-page-peel' ),
					$option_content
				);
				break;
		}
	}

	/**
	 * Add a warning when an AdSense ad is assigned to the page peel placement.
	 *
	 * @param string $_placement_slug
	 * @param arr    $_placement
	 */
	public function add_adsense_warning( $_placement_slug, $_placement ) {
		if ( 'page_peel' !== $_placement['type'] || empty( $_placement['item'] ) ) {
			return;
		}

		if ( ! class_exists( 'Advanced_Ads_Utils' ) || ! method_exists( 'Advanced_Ads_Utils', 'get_nested_ads' ) ) {
			return;
		}

		foreach ( Advanced_Ads_Utils::get_nested_ads( $_placement_slug, 'placement' ) as $ad ) {
			if ( $ad->type === 'adsense' ) { ?>
				<p class="advads-notice-inline advads-error"><?php esc_html_e( 'It is against the AdSense policy to use their ads in popups.', 'advanced-ads-page-peel' ); ?></p>
				<?php
				return;
			}
		}
	}
}
